<?php
/**
 * @author      Lefteris Kavadas
 * @copyright   Copyright (c) 2016 - 2024 Lefteris Kavadas / firecoders.com
 * @license     GNU General Public License version 3 or later
 */
defined('_JEXEC') or die;

use Joomla\CMS\Factory;
use Joomla\CMS\Filesystem\File;
use Joomla\CMS\MVC\View\HtmlView;
use Joomla\CMS\Toolbar\Toolbar;
use Joomla\CMS\Toolbar\ToolbarHelper;
use Joomla\CMS\Language\Text;
use Joomla\CMS\Form\Form;
use Joomla\CMS\Uri\Uri;
use Joomla\CMS\HTML\HTMLHelper;

class Route66ViewAnalysis extends HtmlView
{
	public function display($tpl = null)
	{
		$this->isPro = File::exists(JPATH_SITE . '/plugins/k2/route66seo/media/js/route66analyzer.js');

		$this->loadHelper('html');
		$this->loadHelper('extension');
		$version = Route66HelperExtension::getVersion();

		ToolBarHelper::title(Text::_('COM_ROUTE66_SEO_ANALYSIS_TITLE'), 'search');
		$toolbar = Toolbar::getInstance('toolbar');
		$toolbar->appendButton('Link', 'arrow-left', 'JTOOLBAR_BACK', 'index.php?option=com_route66&view=seo');

		if ($this->isPro)
		{
			HTMLHelper::_('jquery.framework');
			HTMLHelper::_('behavior.formvalidator');
			$document = Factory::getDocument();
			$document->addStyleSheet(Uri::root(true) . '/media/route66/css/route66seo.css', array('version' => $version));
			$this->loadLanguage();
			$document->addScript(Uri::root(true) . '/media/route66/js/seo/main.min.js', array('version' => $version));
			$document->addScript(Uri::root(true) . '/plugins/k2/route66seo/media/js/route66analyzer.js', array('version' => $version));
			Text::script('ERROR');
			Text::script('COM_ROUTE66_YOU_CAN_USE_ONLY_INTERNAL_URLS');

			$this->form = Form::getInstance('route66seoanalysis', JPATH_SITE . '/administrator/components/com_route66/forms/route66seoanalysis.xml', array('control' => 'jform'));

			if (version_compare(JVERSION, '4.0', 'ge'))
			{
				$button = '<joomla-toolbar-button><button onclick="Joomla.submitbutton(\'seo.fetchPage\');" class="btn btn-small btn-success"><span class="fa fa-play" title="' . Text::_('COM_ROUTE66_ANALYZE') . '"></span>' . Text::_('COM_ROUTE66_ANALYZE') . '</button></joomla-toolbar-button>';
			}
			else
			{
				$button = '<button onclick="Joomla.submitbutton(\'seo.fetchPage\');" class="btn btn-small btn-success"><span class="icon-play icon-white" title="' . Text::_('COM_ROUTE66_ANALYZE') . '"></span>' . Text::_('COM_ROUTE66_ANALYZE') . '</button>';
			}

			$toolbar->appendButton('Custom', $button, 'generate');
		}
		else
		{
			$application = Factory::getApplication();
			$application->enqueueMessage(Text::_('COM_ROUTE66_PAGE_CONTENT_ANALYSIS_PRO_FEATURE'), 'warning');
		}

		parent::display($tpl);
	}

	private function loadLanguage()
	{
		$i18n = '';
		$language = Factory::getLanguage();
		$language->load('com_route66', JPATH_ADMINISTRATOR . '/components/com_route66');
		$tag = $language->getTag();
		$locale = str_replace('-', '_', $tag);

		$path = JPATH_ADMINISTRATOR . '/components/com_route66/lib/translations';
		$files = array('wordpress-seo-' . $locale . '.json');

		if (strpos($locale, '_'))
		{
			$parts = explode('_', $locale);
			$files[] = 'wordpress-seo-' . $parts[0] . '.json';
		}

		foreach ($files as $file)
		{
			if (File::exists($path . '/' . $file))
			{
				$buffer = file_get_contents($path . '/' . $file);
				$buffer = str_replace('wordpress-seo', 'js-text-analysis', $buffer);
				$i18n = json_decode($buffer);

				break;
			}
		}

		$document = Factory::getDocument();
		$document->addScriptOptions('Route66UrlAnalyzerOptions', array('i18n' => $i18n, 'worker' => Uri::root(false) . 'media/route66/js/seo/worker.min.js', 'site' => Uri::root(false)));
	}
}
