<?php
/**
 * @author      Lefteris Kavadas
 * @copyright   Copyright (c) 2016 - 2024 Lefteris Kavadas / firecoders.com
 * @license     GNU General Public License version 3 or later
 */
defined('_JEXEC') or die;

use Joomla\CMS\Factory;
use Joomla\CMS\MVC\View\HtmlView;
use Joomla\CMS\Component\ComponentHelper;
use Joomla\CMS\Toolbar\ToolbarHelper;
use Joomla\CMS\Toolbar\Toolbar;
use Joomla\CMS\Language\Text;
use Joomla\CMS\Plugin\PluginHelper;
use Joomla\CMS\Uri\Uri;

class Route66ViewGooglePageSpeed extends HtmlView
{
	public function display($tpl = null)
	{
		$application = Factory::getApplication();

		$this->loadHelper('html');
		$this->loadHelper('extension');
		$this->sidebar = Route66HelperHtml::getSidebar('googlepagespeed');

		ToolBarHelper::title(Text::_('COM_ROUTE66_GOOGLE_PAGESPEED'), 'dashboard');
		$toolbar = ToolBar::getInstance('toolbar');

		if (version_compare(JVERSION, '4', '>='))
		{
			$customButton = '<joomla-toolbar-button><a class="btn btn-primary" href="https://developers.google.com/speed/pagespeed/insights/?url=' . urlencode(Uri::root(false)) . '"><span class="fa fa-link" aria-hidden="true"></span>' . Text::_('COM_ROUTE66_ANALYZE_YOUR_SITE') . '</a></joomla-toolbar-button>';
		}
		else
		{
			$customButton = '<a class="btn btn-small" target="_blank" href="https://developers.google.com/speed/pagespeed/insights/?url=' . urlencode(Uri::root(false)) . '"><i class="icon-new-tab"></i>' . Text::_('COM_ROUTE66_ANALYZE_YOUR_SITE') . '</a>';
		}
		$toolbar->appendButton('Custom', $customButton);

		ToolBarHelper::help(null, false, 'https://www.firecoders.com/documentation/route-66');
		Route66HelperHtml::addOptionsButton();

		if (PluginHelper::isEnabled('system', 'route66pagespeed'))
		{
			Route66HelperExtension::fixPluginsOrdering();
		}
		else
		{
			$application->enqueueMessage(Text::_('COM_ROUTE66_PAGESPEED_PLUGIN_DISABLED_WARNING'), 'warning');
		}

		$this->params = ComponentHelper::getParams('com_route66');

		parent::display($tpl);
	}
}
