<?php
/**
 * @author      Lefteris Kavadas
 * @copyright   Copyright (c) 2016 - 2024 Lefteris Kavadas / firecoders.com
 * @license     GNU General Public License version 3 or later
 */
defined('_JEXEC') or die;

use Joomla\CMS\Factory;
use Joomla\CMS\Router\Route;
use Joomla\CMS\MVC\View\HtmlView;
use Joomla\CMS\Toolbar\ToolbarHelper;
use Joomla\CMS\Toolbar\Toolbar;
use Joomla\CMS\Language\Text;
use Joomla\CMS\Plugin\PluginHelper;
use Joomla\CMS\HTML\HTMLHelper;

class Route66ViewSeo extends HtmlView
{
	protected $items;
	protected $state;
	protected $pagination;

	public function display($tpl = null)
	{
		$this->items = $this->get('Items');
		$this->state = $this->get('State');
		$this->pagination = $this->get('Pagination');
		$this->filterForm = $this->get('FilterForm');
		$this->activeFilters = $this->get('ActiveFilters');

		if (count($errors = $this->get('Errors')))
		{
			throw new \Exception(500, implode("\n", $errors));

			return false;
		}

		ToolBarHelper::title(Text::_('COM_ROUTE66_SEO_SCORES_TITLE'), 'bars');
		$user = Factory::getUser();

		if ($user->authorise('core.edit', 'com_plugins'))
		{
			if (version_compare(JVERSION, '4.0', 'ge'))
			{
				$customButton = '<joomla-toolbar-button><a class="btn btn-small" href="' . Route::_('index.php?option=com_plugins&filter[search]=Route+66+SEO') . '"><span class="fas fa-plug" aria-hidden="true"></span>' . Text::_('COM_ROUTE66_ROUTE66_SEO_PLUGINS') . '</a></joomla-toolbar-button>';
			}
			else
			{
				$customButton = '<a class="btn btn-small" href="' . Route::_('index.php?option=com_plugins&filter[search]=Route+66+SEO') . '"><i class="icon-power-cord plugin"></i>' . Text::_('COM_ROUTE66_ROUTE66_SEO_PLUGINS') . '</a>';
			}
			$toolbar = ToolBar::getInstance('toolbar');
			$toolbar->appendButton('Custom', $customButton);
		}

		$this->loadHelper('html');
		$this->sidebar = Route66HelperHtml::getSidebar('seo');
		Route66HelperHtml::addOptionsButton();

		if (version_compare(JVERSION, '4.0', 'lt'))
		{
			HTMLHelper::_('formbehavior.chosen', 'select');
		}

		if (!PluginHelper::isEnabled('content', 'route66seo') && !PluginHelper::isEnabled('k2', 'route66seo'))
		{
			$application = Factory::getApplication();
			$application->enqueueMessage(Text::_('COM_ROUTE66_SEO_PLUGINS_DISABLED_WARNING'), 'warning');
		}

		parent::display($tpl);
	}
}
