<?php
/**
 * @author      Lefteris Kavadas
 * @copyright   Copyright (c) 2016 - 2024 Lefteris Kavadas / firecoders.com
 * @license     GNU General Public License version 3 or later
 */
defined('_JEXEC') or die;

use Joomla\CMS\Factory;
use Joomla\CMS\Router\Route;
use Joomla\CMS\MVC\View\HtmlView;
use Joomla\CMS\Component\ComponentHelper;
use Joomla\CMS\Toolbar\ToolbarHelper;
use Joomla\CMS\Toolbar\Toolbar;
use Joomla\CMS\Language\Text;
use Joomla\CMS\Plugin\PluginHelper;
use Joomla\CMS\Form\Form;

class Route66ViewUrls extends HtmlView
{
	public function display($tpl = null)
	{
		$application = Factory::getApplication();
		$language = Factory::getLanguage();
		$this->items = array();
		$db = Factory::getDbo();
		$query = $db->getQuery(true);
		$query->select('*')->from($db->qn('#__extensions'))->where($db->qn('type') . ' = ' . $db->q('plugin'))->where($db->qn('folder') . ' = ' . $db->q('route66'));
		$db->setQuery($query);
		$extensions = $db->loadObjectList();

		foreach ($extensions as $extension)
		{
			$language->load('plg_route66_' . $extension->element . '.sys', JPATH_SITE . '/plugins/route66/' . $extension->element);
			$extension->form = new Form($extension->name);
			$extension->form->loadFile(JPATH_SITE . '/plugins/route66/' . $extension->element . '/' . $extension->element . '.xml', false, '//config');
			$params = (array) json_decode($extension->params);

			foreach ($params as $key => $param)
			{
				$params[$key] = (array) $param;
			}
			$data = array('params' => $params);
			$extension->form->bind($data);
			$extension->rules = array();

			foreach ($extension->form->getFieldset() as $field)
			{
				if ($field->type == 'Route66Pattern')
				{
					$field->readonly = true;
					$field->disabled = true;
					$rule = new stdClass();
					$rule->label = Text::_($extension->form->getFieldAttribute($field->fieldname, 'label', null, 'params'));
					$rule->input = $field->input;
					$extension->rules[] = $rule;
				}
			}

			if (count($extension->rules))
			{
				$this->items[] = $extension;
			}
		}
		$this->canEditPlugins = Factory::getUser()->authorise('core.edit', 'com_plugins');
		$document = Factory::getDocument();
		$document->addStyleDeclaration('#patternsList .muted { display: none;} #patternsList .control-group { margin: 4px 0; } #patternsList td {vertical-align: middle} #patternsList input {cursor: unset;box-shadow: none;}');

		ToolBarHelper::title(Text::_('COM_ROUTE66_URLS_TITLE'), 'link');

		if ($this->canEditPlugins)
		{
			if (version_compare(JVERSION, '4.0', 'ge'))
			{
				$customButton = '<joomla-toolbar-button><a class="btn btn-small" href="' . Route::_('index.php?option=com_plugins&filter[folder]=route66') . '"><span class="fas fa-plug" aria-hidden="true"></span>' . Text::_('COM_ROUTE66_ROUTE66_PLUGINS') . '</a></joomla-toolbar-button>';
			}
			else
			{
				$customButton = '<a class="btn btn-small" href="' . Route::_('index.php?option=com_plugins&filter[folder]=route66') . '"><i class="icon-power-cord plugin"></i>' . Text::_('COM_ROUTE66_ROUTE66_PLUGINS') . '</a>';
			}
			$toolbar = ToolBar::getInstance('toolbar');
			$toolbar->appendButton('Custom', $customButton);
		}
		$this->loadHelper('html');
		$this->loadHelper('extension');
		$this->sidebar = Route66HelperHtml::getSidebar('urls');
		Route66HelperHtml::addOptionsButton();
		ToolBarHelper::help(null, false, 'https://www.firecoders.com/documentation/route-66');

		if (!PluginHelper::isEnabled('system', 'route66'))
		{
			$application->enqueueMessage(Text::_('COM_ROUTE66_SYSTEM_PLUGIN_DISABLED_WARNING'), 'warning');
		}
		else
		{
			Route66HelperExtension::fixPluginsOrdering();
		}
		$this->params = ComponentHelper::getParams('com_route66');

		parent::display($tpl);
	}
}
