<?php
/**
 * @author      Lefteris Kavadas
 * @copyright   Copyright (c) 2016 - 2024 Lefteris Kavadas / firecoders.com
 * @license     GNU General Public License version 3 or later
 */
defined('_JEXEC') or die;

use Joomla\CMS\Factory;
use Joomla\CMS\Language\Text;
use Joomla\Registry\Registry;
use Joomla\CMS\Form\FormRule;
use Joomla\CMS\Form\Form;

class JFormRuleRoute66Pattern extends FormRule
{
	private $tokens;
	private $identifiers;

	public function test(SimpleXMLElement $element, $value, $group = null, Registry $input = null, Form $form = null)
	{
		$language = Factory::getLanguage();
		$language->load('plg_system_route66.sys', JPATH_SITE . '/plugins/system/route66');

		$this->identifiers = explode(',', (string) $element->attributes()->identifiers);
		$this->tokens = array_merge($this->identifiers, explode(',', (string) $element->attributes()->tokens));

		foreach ($value as $data)
		{
			if ($data)
			{
				$tokens = array();
				$matches = array();
				preg_match_all('/{(.*?)}/', $data, $matches, PREG_SET_ORDER);

				if (is_array($matches) && count($matches))
				{
					foreach ($matches as $match)
					{
						if (!in_array($match[1], $this->tokens))
						{
							return new UnexpectedValueException(Text::sprintf('PLG_SYSTEM_ROUTE66_INVALID_TOKEN_USED', $match[1], Text::_($element->attributes()->label)));
						}
						$tokens[] = $match[1];
					}
					$tokens = array_unique($tokens);
					$intersection = array_intersect($tokens, $this->identifiers);

					if (count($intersection) == 0)
					{
						return new UnexpectedValueException(Text::sprintf('PLG_SYSTEM_ROUTE66_NO_IDENTIFIER_PROVIDED', Text::_($element->attributes()->label)));
					}
				}
				else
				{
					return new UnexpectedValueException(Text::sprintf('PLG_SYSTEM_ROUTE66_INVALID_PATTERN', Text::_($element->attributes()->label)));
				}
			}
		}

		return true;
	}
}
